<?xml version="1.0"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

	<!-- The root element is "testing" -->
	<xsl:template match="testing">
		<html>
			<head>
				<meta http-equiv="X-UA-Compatible" content="IE=Edge" />
				<link href="TestingInstructions.css" rel="stylesheet" type="text/css" />
				<title><xsl:value-of select="title"/> - OpticonUSA.com</title>
			</head>
			<body>
				<div id="container">
					<div id="header">
						<img src="TestingInstructions/OpticonLogo.jpg" border="0"/>
					</div>
					<p><a name="top"/>Instruction Steps - <xsl:apply-templates select="step" mode="enumerate"/></p>
					<p><a name="top"></a><xsl:copy-of select="introduction"/></p>
					<table class="hoverTable" id="bounded" border="1" cellspacing="3" cellpadding="3">
						<tr>
							<th>Step</th>
							<th>Instructions</th>
							<th>Guidelines</th>
							<!-- <th>Goals</th> -->
						</tr>
						<xsl:apply-templates select="step"/>
					</table>
					<p class="pageBreak"/>
					<xsl:apply-templates select="notes"/>
					<hr/>
					<xsl:if test="//./*[@flowchart!='']">
						<h2>Supporting Flowcharts - </h2>
						<ol><xsl:apply-templates select="//./*[@flowchart!='']" mode="enumerate"/></ol><hr/>
					</xsl:if>
					<h2>Supporting images -</h2>
						<ol>
							<xsl:apply-templates select="/testing/images/image" mode="enumerate">
								<xsl:sort select="alt"/>
							</xsl:apply-templates>
						</ol><hr/>
					<h2>Supporting files - </h2>
						<ol>
							<xsl:apply-templates select="//./img[@alt!='']|//./a[@alt!='']" mode="enumerate">
								<xsl:sort select="@alt"/>
							</xsl:apply-templates>
						</ol>
				</div>
			</body>
		</html>
	</xsl:template>
	
	<!-- identify any notes to exercise for testing -->
	<xsl:template match="notes">
		<h2>Notes during board testing :</h2>
		<ol type="1">
			<xsl:apply-templates select="note"/>
		</ol>
	</xsl:template>
	<xsl:template match="note">
		<li><xsl:apply-templates/></li>
	</xsl:template>

	<!-- Identify steps to go through when testing -->
	<xsl:template match="step" mode="enumerate">
		<a><xsl:attribute name="href">#step<xsl:value-of select="position()"/></xsl:attribute><xsl:attribute name="title"><xsl:value-of select="goal/p[1]"/></xsl:attribute><xsl:if test="position() = 1 or position() = last()">Step</xsl:if> # <xsl:value-of select="position()"/></a><xsl:if test="position() != last()">, </xsl:if>
	</xsl:template>

	<!-- Enumerate images present -->
	<xsl:template match="img|a" mode="enumerate">
		<li><a target="_blank" title="{@alt}" href="{@src|@href}"><xsl:value-of select="@alt"/></a></li>
	</xsl:template>
	<xsl:template match="image" mode="enumerate">
		<li><a target="_blank" title="{alt}" href="{/testing/images/@dir}/{ref}"><xsl:value-of select="alt"/></a></li>
	</xsl:template>

	<!-- Enumerate flowcharts from instruction, guideline, or goal elements -->
	<xsl:template match="instruction|guideline|goal" mode="enumerate">
		<li><a target="_top" title="Flowchart - {@alt}" href="{/testing/images/@dir}/{@flowchart}.jpg">Flowchart - <xsl:value-of select="@alt"/></a></li>
	</xsl:template>
	
	<!-- Generate instruction steps table -->
	<xsl:template match="step">
		<xsl:variable name="step">step<xsl:value-of select="position()"/></xsl:variable>
		<tr>
			<td>
				<a><xsl:attribute name="name"><xsl:value-of select="$step"/></xsl:attribute><xsl:attribute name="id"><xsl:value-of select="$step"/></xsl:attribute></a>
			</td>
			<td><xsl:apply-templates select="instruction"/></td>
			<td><xsl:apply-templates select="guideline"/></td>
			<!-- <td><xsl:apply-templates select="goal"/></td> -->
		</tr>
	</xsl:template>

	<!-- picture tooltip -->
	<xsl:template match="picture">
		<xsl:variable name="tooltip" select="@tooltip"/>
		<xsl:variable name="image" select="/testing/images/image[@tooltip=$tooltip]"/>
		<xsl:variable name="text">
			<xsl:choose>
				<xsl:when test="text()"><xsl:apply-templates/></xsl:when>
				<xsl:when test="@text"><xsl:value-of select="@text"/></xsl:when>
				<xsl:otherwise><xsl:value-of select="@tooltip"/></xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		<a class="tooltip" href="{/testing/images/@dir}/{$image/ref}" target="_blank"><xsl:if test="@name"><xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute></xsl:if><xsl:copy-of select="$text"/><span class="custom info"><img src="{/testing/images/@dir}/{$image/ref}" alt="{$image/alt}"><xsl:if test="$image/@height"><xsl:attribute name="height"><xsl:value-of select="$image/@height"/></xsl:attribute><xsl:attribute name="width"><xsl:value-of select="$image/@width"/></xsl:attribute></xsl:if></img></span></a>
	</xsl:template>
	
	<!-- Add flowcharts where needed -->
	<!-- <xsl:template match="instruction|guideline|goal"> -->
	<xsl:template match="instruction|guideline">
		<xsl:apply-templates/><xsl:if test="@flowchart"><br/><br/><p><a class="tooltip" href="{/testing/images/@dir}/{@flowchart}.htm" target="_blank"><xsl:if test="@name"><xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute></xsl:if>Flowchart<span class="custom info"><img src="{/testing/images/@dir}/{@flowchart}.jpg" alt="{alt}"><xsl:if test="@height"><xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute><xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute></xsl:if></img></span></a></p></xsl:if>
	</xsl:template>

	<!-- Process all elements -->
	<xsl:template match="node() | @*">
		<xsl:copy>
			<xsl:apply-templates select="node() | @*" />
		</xsl:copy>
	</xsl:template>
	
</xsl:stylesheet>